@@ -25,7 +25,7 @@ const walls_config: { [key: string]: any } = {
     y: 25,
     stroke: 'darkred',
     strokeWidth: 7,
-    dash: [10, 10],
+    dash: [5, 5],
   },
 };
 export class WorldModel {
@@ -40,13 +40,14 @@ export class WorldModel {
   objects: any;
   tileMap: any;
   tiles: any;
+  pending_goals: any;
   ui: {
     wrapper: HTMLDivElement;
     stage?: Konva.Stage;
     layers: {
       main: Konva.Layer;
       line: Konva.Layer;
-      msg: Konva.Layer;
+      msg?: Konva.Layer;
       bg: Konva.Layer;
     };
   };
@@ -63,7 +64,8 @@ export class WorldModel {
     robots = [],
     objects = {},
     tileMap = {},
-    tiles = []
+    tiles = [],
+    pending_goals = []
   ) {
     this.rows = rows;
     this.cols = cols;
@@ -75,6 +77,7 @@ export class WorldModel {
     this.objects = objects;
     this.tileMap = tileMap;
     this.tiles = tiles;
+    this.pending_goals = pending_goals;
     this.draw_canvas();
 
     this.robots = robots.map(
@@ -97,6 +100,8 @@ export class WorldModel {
   init_ui() {
     let wrapper = document.createElement('div');
     wrapper.setAttribute('class', 'ttgt-wrapper');
+    let msg = document.createElement('div');
+    msg.setAttribute('class', 'ttgt-msg');
 
     let elem = document.createElement('div');
     elem.setAttribute('id', 'container');
@@ -119,36 +124,119 @@ export class WorldModel {
     this.ui = {
       wrapper,
       layers: {
-        bg: new Konva.Layer(),
-        main: new Konva.Layer(),
-        line: new Konva.Layer(),
-        msg: new Konva.Layer(),
+        bg: new Konva.Layer({ offsetY: -150 }),
+        main: new Konva.Layer({ offsetY: -150 }),
+        line: new Konva.Layer({ offsetY: -150 }),
       },
     };
   }
 
   draw_canvas() {
     let padding = 25;
+    let msgHeight = 150;
     let stage = new Konva.Stage({
       container: 'container',
       width: this.width + this.bs + padding,
-      height: this.height + this.bs + padding,
+      height: this.height + this.bs + padding + msgHeight,
     });
 
+    this.ui.layers.msg = new Konva.Layer({
+      width: this.width + this.bs + padding,
+      height: msgHeight,
+    });
+
+    stage.add(this.ui.layers.msg);
     stage.add(this.ui.layers.bg);
     stage.add(this.ui.layers.main);
     stage.add(this.ui.layers.line);
-    stage.add(this.ui.layers.msg);
     this.ui.stage = stage;
 
     //draw stage
     this.draw_border();
     this.draw_grid();
     this.draw_objects();
+    this.draw_msg_containers();
+
+    if (this.pending_goals.length > 0) {
+      this.draw_pending_instructions(this.pending_goals, 'red');
+    } else {
+      this.draw_pending_instructions(this.pending_goals);
+    }
 
     this.ui.layers.main.draw();
   }
 
+  draw_msg_containers() {
+    let msg_layer = this.ui.layers.msg;
+    let title = new Konva.Text({
+      y: 10,
+      width: msg_layer?.width(),
+      align: 'center',
+      verticalAlign: 'center',
+      height: 20,
+      fontSize: 24,
+      text: 'Pending Tasks',
+    });
+
+    this.ui.layers.msg?.add(title);
+    this.ui.layers.msg?.draw();
+  }
+
+  draw_pending_instructions(
+    msgs = ['No Goal'],
+    color = 'black',
+    fontSize = 16
+  ) {
+    let msg_layer = this.ui.layers.msg;
+
+    let old_msg = this.ui.layers.msg?.find(`.instruction_msg`)[0];
+
+    if (old_msg) {
+      old_msg.destroy();
+    }
+
+    let msg = msgs.slice(0, 6).join('\n\n');
+    let rect_width = Math.max(msg_layer?.width() || 0, 200) - 70;
+    let text = new Konva.Text({
+      padding: 20,
+      text: msg,
+      x: 40,
+      y: 40,
+      align: 'center',
+      fill: color,
+      verticalAlign: 'center',
+      fontSize: fontSize,
+      width: rect_width,
+      name: 'instruction_msg-rect',
+    });
+
+    let rect = new Konva.Rect({
+      width: rect_width,
+      height: text.height(),
+      cornerRadius: 10,
+      stroke: 'black',
+      x: 40,
+      y: 40,
+      name: 'instruction_msg',
+    });
+    msg_layer?.add(rect);
+    msg_layer?.add(text);
+    msg_layer?.draw();
+  }
+
+  success_msg(msg: string | string[]) {
+    let arr: string[] = [];
+
+    let old_msg = this.ui.layers.msg?.find(`.instruction_msg`)[0];
+    let old_msg_rect = this.ui.layers.msg?.find(`.instruction_msg-rect`)[0];
+
+    if (old_msg) {
+      old_msg.destroy();
+      old_msg_rect?.destroy();
+    }
+    return this.draw_pending_instructions(arr.concat(msg), 'green', 20);
+  }
+
   draw_objects() {
     for (const key in this.objects) {
       const [x, y] = key.split(',').map((zz) => parseInt(zz));
@@ -417,6 +505,10 @@ export class WorldModel {
     this.hwalls.forEach((hw: any, i: number) => {
       hw.forEach((val: number, j: number) => {
         if (val) {
+          300;
+          300;
+          300;
+          300;
           this.draw_typed_wall(i, j, 'north', val);
         } else {
           this.remove_wall(i, j, 'north');
