@@ -13,13 +13,14 @@ DEFAULT_OBJECTS = [
     'tulip',
     'daisy',
     'star',
-
+    "green_home_tile",
     'mud',
     'gravel',
     'pale_grass',
     'water',
     'ice',
     'grass',
+    "house"
 ]
 
 
