@@ -91,7 +91,11 @@ class WorldParser:
             x,y = random.choice(position_goal)
             self.world._add_goal('position', {"x": x, "y": y})
         elif goals.get('position', None) is not None:
-            self.world._add_goal('position', goals.get('position', None))
+            pos = goals.get('position', None)
+            self.world._add_goal('position', pos)
+            image = pos.get("image",None)
+            if image is not None:
+                self.world.add_tile(pos["x"], pos["y"], image)
     
     def add_wall_goals(self, walls = {}):
         for xy, wall in walls.items():
